/*
 * Copyright 2006 The Apache Software Foundation.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shale.tiger.register;

import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

/**
 * <p>Method-level annotation indicating that this method should be called
 * to process the "after phase" handling for the containing phase listener.</p>
 *
 * <p><strong>ASSERTION</strong> - The containing class is annotated with
 * the {@link FacesPhaseListener} annotation.</p>
 *
 * <p><strong> ASSERTION</strong> - The annotated method has a return type
 * of <code>void</code> and accepts a single parameter of type
 * <code>javax.faces.event.PhaseEvent</code>.</p>
 *
 * @since 1.0.3
 */
@Retention(RetentionPolicy.RUNTIME)
@Target(ElementType.METHOD)
public @interface AfterPhase {

}
